@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2002 Damir Zucic */
 
 /*=============================================================================
 
@@ -59,6 +59,11 @@ int			screen_x, screen_y;
 size_t			pixelI;
 NearestAtomS		*curr_pixelSP;
 double			z;
+int			bondI;
+
+/* Initialize the bond index. The negative value means that pixels */
+/* filled  in this function  are not a part of some chemical bond. */
+bondI = -1;
 
 /* Number of images: */
 if (configSP->stereoF) imagesN = 2;
@@ -121,8 +126,8 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 
 		/* Check is this pixel inside the area reserved for the */
 		/* current image (there are two images in stereo mode): */
-		if (screen_x < left_edge[imageI]) break;
-		if (screen_x > right_edge[imageI]) break;
+		if (screen_x <  left_edge[imageI])  break;
+		if (screen_x >= right_edge[imageI]) break;
 
 		/* Prepare index  to the array */
 		/* of NearestAtomS structures: */
@@ -157,6 +162,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->left_colorID;
 
@@ -216,6 +222,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->left_colorID;
 
@@ -275,6 +282,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->left_colorID;
 
@@ -340,6 +348,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->middle_colorID;
 
@@ -399,6 +408,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->middle_colorID;
 
@@ -458,6 +468,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->middle_colorID;
 
@@ -523,6 +534,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->right_colorID;
 
@@ -582,6 +594,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->right_colorID;
 
@@ -641,6 +654,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		curr_pixelSP->last_refreshI = refreshI;
 		curr_pixelSP->mol_complexI = mol_complexI;
 		curr_pixelSP->atomI = atomI;
+		curr_pixelSP->bondI = bondI;
 		curr_pixelSP->z = z;
 		curr_pixelSP->colorID = curr_atomSP->right_colorID;
 
