@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -67,6 +67,7 @@ int		Zebra_ (MolComplexS *, int, GUIS *, ColorSchemeS *);
 int		Chain_ (MolComplexS *, int, GUIS *, ColorSchemeS *);
 int		ColorHyphob_ (MolComplexS *, int, GUIS *, ColorSchemeS *);
 int		ColorModel_ (MolComplexS *, int, GUIS *, ColorSchemeS *);
+int		ColorSize_ (MolComplexS *, int, GUIS *, ColorSchemeS *);
 
 /*======simple color schemes:================================================*/
 
@@ -84,7 +85,8 @@ static char		scheme_nameAA[COLORSCHEMES][SHORTSTRINGSIZE] =
 				 "ORANGE", "HOT", "COLD",
 				 "MONOCHROME", "CPK", "ZEBRA",
 				 "CHAIN", "HYPHOB", "MODEL",
-				 "ORANGE-YELLOW", "ORANGE-RED"};
+				 "ORANGE-YELLOW", "ORANGE-RED", "SKIN",
+				 "SIZE"};
 int			schemeI = -1;
 ColorSchemeS		*color_schemeSP;
 int			i;
@@ -143,6 +145,7 @@ if (modeI == 1)
 		case 12:	/* ORANGE        */
 		case 21:	/* ORANGE-YELLOW */
 		case 22:	/* ORANGE-RED    */
+		case 23:	/* SKIN          */
 
 			/* Pointer to the color scheme: */
 			color_schemeSP = color_schemeSA + schemeI;
@@ -204,6 +207,7 @@ if (modeI == 2)
 		case 12:	/* ORANGE        */
 		case 21:	/* ORANGE-YELLOW */
 		case 22:	/* ORANGE-RED    */
+		case 23:	/* SKIN          */
 
 			/* Pointer to the color scheme: */
 			color_schemeSP = color_schemeSA + schemeI;
@@ -282,6 +286,14 @@ else if (schemeI == 20)
 			    guiSP, color_schemeSA);
 	}
 
+/*......SIZE:...............................................................*/
+
+else if (schemeI == 24)
+	{
+	return ColorSize_ (mol_complexSP, mol_complexesN,
+			   guiSP, color_schemeSA);
+	}
+
 /*......other schemes:.......................................................*/
 
 /* The number of color surfaces: */
