@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2003 Damir Zucic */
+/* Copyright (C) 2001-2004 Damir Zucic */
 
 
 /* Command codes - return values from ExecuteCommand_ () function. */
@@ -69,6 +69,7 @@
 #define COMMAND_BALLS         61
 #define COMMAND_BLUR          62
 #define COMMAND_GROUP         63
+#define COMMAND_DUMP          64
 
 
 /* Negative (error) codes: */
@@ -139,5 +140,6 @@
 #define ERROR_BALLS          -64
 #define ERROR_BLUR           -65
 #define ERROR_GROUP          -66
+#define ERROR_DUMP           -67
 
 
