@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2003 Damir Zucic */
+/* Copyright (C) 2001-2004 Damir Zucic */
 
 
 /* Defines used in garlic program. */
@@ -202,7 +202,7 @@
 
 /* The number of hydrophobicity scales which are hard-coded in the program: */
 
-#define SCALESN              3
+#define SCALESN              6
 
 
 /* The minimal spacing of slab surfaces: */
@@ -238,7 +238,7 @@
 
 /* Number of predefined (hard-coded) color schemes: */
 
-#define COLORSCHEMES        23
+#define COLORSCHEMES        25
 
 
 /* The identifier used to identify H to H bond (must be negative!): */
@@ -280,6 +280,21 @@
 #define MAXRESIDUES      20000
 
 
+/* The maximal pattern length (the maximal number of sets in pattern): */
+
+#define MAX_PATT_LENGTH    100
+
+
+/* For each position in the pattern, more than one residue may be specified. */
+/* The following symbol defines the maximal number of residues per position: */
+
+#define MAX_NAMES_IN_SET    30
+
+
+/* The maximal number of residues in the pattern buffer: */
+#define MAX_RES_IN_PATT   3000
+
+
 /* The value which signals that dihedral angle is missing (not calculated): */
 
 #define BADDIHEDANGLE    999.0
@@ -298,17 +313,6 @@
 #define ENVELOPE_MASK      0x8
 
 
-/* The maximal pattern length: */
-
-#define MAXPATTLENGTH       50
-
-
-/* For each position in the pattern, more than one residue may be specified. */
-/* The following symbol defines the maximal number of residues per position: */
-
-#define MAXPATTNAMES        50
-
-
 /* The gap between two objects prepared for docking (in angstroms): */
 
 #define DOCKING_GAP          4
@@ -344,7 +348,7 @@
 
 /* Sequence neighborhood half width: */
 
-#define NEIGH_HALF_WIDTH          5
+#define NEIGH_HALF_WIDTH          11
 
 
 /* The omega angle tolerance (degrees). For a */
