@@ -40,6 +40,7 @@ int FreeRuntime_ (RuntimeS *runtimeSP)
 if (runtimeSP->commandsP)		free (runtimeSP->commandsP);
 if (runtimeSP->titlesP)			free (runtimeSP->titlesP);
 if (runtimeSP->sequenceP)		free (runtimeSP->sequenceP);
+if (runtimeSP->patternP)		free (runtimeSP->patternP);
 if (runtimeSP->sec_structureP)		free (runtimeSP->sec_structureP);
 if (runtimeSP->disulfideFP)		free (runtimeSP->disulfideFP);
 if (runtimeSP->serialIP)		free (runtimeSP->serialIP);
@@ -47,19 +48,32 @@ if (runtimeSP->residue_codeIP)		free (runtimeSP->residue_codeIP);
 if (runtimeSP->hydrophobicityP)		free (runtimeSP->hydrophobicityP);
 
 if (runtimeSP->average_hydrophobicityP)
-			free (runtimeSP->average_hydrophobicityP);
+				free (runtimeSP->average_hydrophobicityP);
 if (runtimeSP->hydrophobic_momentP)
-			free (runtimeSP->hydrophobic_momentP);
+				free (runtimeSP->hydrophobic_momentP);
+if (runtimeSP->larger_sided_hyphobP)
+				free (runtimeSP->larger_sided_hyphobP);
+if (runtimeSP->smaller_sided_hyphobP)
+				free (runtimeSP->smaller_sided_hyphobP);
+
+if (runtimeSP->function1P)		free (runtimeSP->function1P);
+if (runtimeSP->function2P)		free (runtimeSP->function2P);
+if (runtimeSP->function3P)		free (runtimeSP->function3P);
+if (runtimeSP->function4P)		free (runtimeSP->function4P);
+if (runtimeSP->function5P)		free (runtimeSP->function5P);
+
+if (runtimeSP->auxiliaryIP)		free (runtimeSP->auxiliaryIP);
+
 if (runtimeSP->reference_sequenceP)
-			free (runtimeSP->reference_sequenceP);
+				free (runtimeSP->reference_sequenceP);
 if (runtimeSP->reference_sec_structureP)
-			free (runtimeSP->reference_sec_structureP);
+				free (runtimeSP->reference_sec_structureP);
 if (runtimeSP->reference_serialIP)
-			free (runtimeSP->reference_serialIP);
+				free (runtimeSP->reference_serialIP);
 if (runtimeSP->reference_residue_codeIP)
-			free (runtimeSP->reference_residue_codeIP);
+				free (runtimeSP->reference_residue_codeIP);
 if (runtimeSP->reference_hydrophobicityP)
-			free (runtimeSP->reference_hydrophobicityP);
+				free (runtimeSP->reference_hydrophobicityP);
 
 if (runtimeSP->exposed_atom1IP)		free (runtimeSP->exposed_atom1IP);
 if (runtimeSP->exposed_atom2IP)		free (runtimeSP->exposed_atom2IP);
