@@ -2,7 +2,7 @@
 
     o-------------------------------------------------------------------o
     |                                                                   |
-    | Copyright (C) 2000-2003 Damir Zucic                               |
+    | Copyright (C) 2000-2004 Damir Zucic                               |
     |                                                                   |
     | This program is free software; you can redistribute it and/or     |
     | modify it under the terms of the GNU General Public License       |
@@ -339,7 +339,7 @@ if (guiSP->displaySP) XCloseDisplay (guiSP->displaySP);
 if (mol_complexSP) free (mol_complexSP);
 
 /* Close log file if used at all: */
-if (configSP->log_fileP != NULL) fclose (configSP->log_fileP);
+if (configSP->log_fileF != 0) fclose (configSP->log_fileP);
 
 /* Free ConfigS structure: */
 if (configSP) free (configSP);
@@ -348,10 +348,10 @@ if (configSP) free (configSP);
 if (guiSP) free (guiSP);
 
 /* Return on failure: */
-if (mainI < 0) return (EXIT_FAILURE);
+if (mainI < 0) return EXIT_FAILURE;
 
 /* Return on success: */
-return (EXIT_SUCCESS);
+return EXIT_SUCCESS;
 }
 
 /*===========================================================================*/
