@@ -9,8 +9,8 @@ Purpose:
 	every atom. This function generates the internal bonds; it is not
 	enabled to generate the bonds between two complexes. If bonds are
 	available  already,  just  change  the bond  drawing style.  This
-	function was heavily modified for garlic version 1.3,  to improve
-	the identification of hydrogen bonds. Four parameters are used to
+	function was heavily modified  since version 1.3,  to improve the
+	identification of  hydrogen  bonds.  Four parameters  are used to
 	check the validity of hydrogen bonds:
 
 	(1) r12, the distance between two electric dipoles.
@@ -475,8 +475,6 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 	    if (r12 <= 2.0) continue;      /* This covers zero value! */
 	    reciprocal_r12 = 1.0 / r12;
 
-	    if (r12 > 3.7) continue;
-
 	    /* Calculate  and  check  cos_theta1,  the cosine  of the */
 	    /* angle between  the first dipole and the vector between */ 
 	    /* two dipoles.  This cosine belongs to the hydrogen bond */
@@ -504,6 +502,15 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 	    cos_theta12 = ScalarProduct_ (&unit_vector1S, &unit_vector2S);
 	    if (cos_theta12 < 0.0) continue;
 
+	    /*@@*/ /* CONTINUE HERE! */
+	    /*------------------------------------------------------*/
+	    /* @@  Some job should be done to finish this function: */
+	    /* (1) Collect and analyse the best structures.         */
+	    /* (2) Prepare the cryteria for decision what is a good */
+	    /*     hydrogen bond and what is not.                   */
+	    /* (3) Add these cryteria to this function.             */
+	    /*------------------------------------------------------*/
+
 	    /* If this point is reached, add a new */
 	    /* bond to both atoms  (O = 1, N = 2): */
 	    distance = sqrt (distance_squared);
