@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2004 Damir Zucic */
 
 /*=============================================================================
 
@@ -48,7 +48,7 @@ int Include_ (SelectS *include_selectSP, char *stringP)
 {
 char		string_copyA[STRINGSIZE];
 char		*remainderP;
-char		tokenA[SHORTSTRINGSIZE];
+char		tokenA[STRINGSIZE];
 char		*exceptP;
 
 /* Copy the input string to preserve it: */
@@ -60,7 +60,7 @@ string_copyA[STRINGSIZE - 1] = '\0';
 remainderP = stringP;
 
 /* The first token should contain chain identifiers: */
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -1;
 
 /* Remove the exc (exclude, except) keyword and everything after it: */
@@ -70,7 +70,7 @@ if ((exceptP = strstr (tokenA, "EXC")) != NULL) *exceptP = '\0';
 if (ExtractChains_ (include_selectSP, tokenA) < 0) return -2;
 
 /* The second token should contain residue ranges: */
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -3;
 
 /* Remove the exc (exclude, except) keyword and everything after it: */
@@ -80,7 +80,7 @@ if ((exceptP = strstr (tokenA, "EXC")) != NULL) *exceptP = '\0';
 if (ExtractResidueRanges_ (include_selectSP, tokenA) < 0) return -4;
 
 /* The third token should contain residue names: */ 
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -5;
 
 /* Remove the exc (exclude, except) keyword and everything after it: */
@@ -90,7 +90,7 @@ if ((exceptP = strstr (tokenA, "EXC")) != NULL) *exceptP = '\0';
 if (ExtractResidueNames_ (include_selectSP, tokenA) < 0) return -6;
 
 /* The fourth (the last) token should contain atom names: */ 
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -7;
 
 /* Remove the exc (exclude, except) keyword and everything after it: */
