@@ -175,6 +175,32 @@ if (runtimeSP->sequenceP == NULL)
 /* Initialize the secondary structure length: */
 runtimeSP->sec_structure_length = 0;
 
+/* Initialize the size of the pattern buffer: */
+runtimeSP->pattern_buffer_size = MAX_RES_IN_PATT * (RESNAMESIZE - 1);
+
+/* Initialize the number of residues in the pattern buffer: */
+runtimeSP->residues_in_patternN = 0; 
+
+/* Initialize the pattern tolerance: */
+runtimeSP->pattern_tolerance = 0;
+
+/* Allocate the pattern buffer: */
+elementsN = runtimeSP->pattern_buffer_size;
+runtimeSP->patternP = (char *) calloc (elementsN, char_size);
+if (runtimeSP->patternP == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate the pattern buffer!\n",
+		"", "", "");
+	return -4;
+	}
+
+/* Initialize the array with the number of residues per set: */
+for (i = 0; i < MAX_PATT_LENGTH; i++)
+	{
+	runtimeSP->namesNA[i] = 0;
+	}
+
 /* Allocate the secondary structure buffer: */
 elementsN = MAXRESIDUES;
 runtimeSP->sec_structureP = (char *) calloc (elementsN, char_size);
@@ -183,7 +209,7 @@ if (runtimeSP->sec_structureP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate the secondary structure buffer!\n",
 		"", "", "");
-	return -4;
+	return -5;
 	}
 
 /* Allocate memory for disulfide flags (see typedefs.h): */
@@ -194,7 +220,7 @@ if (runtimeSP->disulfideFP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for disulfide flags!\n",
 		"", "", "");
-	return -5;
+	return -6;
 	}
 
 /* Allocate memory for serial numbers: */
@@ -205,7 +231,7 @@ if (runtimeSP->serialIP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for residue serial numbers!\n",
 		"", "", "");
-	return -6;
+	return -7;
 	}
 
 /* Allocate memory for numeric residue codes: */
@@ -216,7 +242,7 @@ if (runtimeSP->residue_codeIP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for numeric residue codes!\n",
 		"", "", "");
-	return -7;
+	return -8;
 	}
 
 /* Allocate memory for hydrophobicity values: */
@@ -227,7 +253,7 @@ if (runtimeSP->hydrophobicityP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for hydrophobicity values!\n",
 		"", "", "");
-	return -8;
+	return -9;
 	}
 
 /* Allocate memory for average hydrophobicity: */
@@ -238,7 +264,7 @@ if (runtimeSP->average_hydrophobicityP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for average hydrophobicity!\n",
 		"", "", "");
-	return -9;
+	return -10;
 	}
 
 /* Allocate memory for hydrophobic moment: */
@@ -249,9 +275,96 @@ if (runtimeSP->hydrophobic_momentP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for hydrophobic moment!\n",
 		"", "", "");
-	return -10;
+	return -11;
 	}
 
+/* Allocate memory for sided hydrophobicity (two buffers): */
+elementsN = MAXRESIDUES;
+runtimeSP->larger_sided_hyphobP = (double *) calloc (elementsN, double_size);
+if (runtimeSP->larger_sided_hyphobP == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+	    "Failed to allocate memory for larger sided hydrophobicity!\n",
+	    "", "", "");
+	return -12;
+	}
+runtimeSP->smaller_sided_hyphobP = (double *) calloc (elementsN, double_size);
+if (runtimeSP->smaller_sided_hyphobP == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+	    "Failed to allocate memory for smaller sided hydrophobicity!\n",
+	    "", "", "");
+	return -13;
+	}
+
+/* Allocate memory for hydrophobicity function F1: */
+elementsN = MAXRESIDUES;
+runtimeSP->function1P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function1P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F1!\n",
+		"", "", "");
+	return -14;
+	}
+
+/* Allocate memory for hydrophobicity function F2: */
+elementsN = MAXRESIDUES;
+runtimeSP->function2P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function2P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F2!\n",
+		"", "", "");
+	return -15;
+	}
+
+/* Allocate memory for hydrophobicity function F3: */
+elementsN = MAXRESIDUES;
+runtimeSP->function3P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function3P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F3!\n",
+		"", "", "");
+	return -16;
+	}
+
+/* Allocate memory for hydrophobicity function F4: */
+elementsN = MAXRESIDUES;
+runtimeSP->function4P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function4P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F4!\n",
+		"", "", "");
+	return -17;
+	}
+
+/* Allocate memory for hydrophobicity function F5: */
+elementsN = MAXRESIDUES;
+runtimeSP->function5P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function5P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F5!\n",
+		"", "", "");
+	return -18;
+	}
+
+/* Allocate memory for auxiliary integers: */
+elementsN = MAXRESIDUES;
+runtimeSP->auxiliaryIP = (int *) calloc (elementsN, int_size);
+if (runtimeSP->auxiliaryIP == NULL)
+        {
+        ErrorMessage_ ("garlic", "InitRuntime_", "",
+                "Failed to allocate memory",
+                " for auxiliary integers!\n",
+                "", "");
+        return -19;
+        }
+
+
 /* Initialize the number of residues in the reference sequence buffer: */
 runtimeSP->reference_residuesN = 0;
 
@@ -263,7 +376,7 @@ if (runtimeSP->reference_sequenceP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate the reference sequence buffer!\n",
 		"", "", "");
-	return -11;
+	return -20;
 	}
 
 /* Initialize the reference secondary structure length: */
@@ -278,7 +391,7 @@ if (runtimeSP->reference_sec_structureP == NULL)
 		"Failed to allocate",
 		" the reference secondary structure buffer!\n",
 		"", "");
-	return -12;
+	return -21;
 	}
 
 /* Allocate memory for reference serial numbers: */
@@ -290,7 +403,7 @@ if (runtimeSP->reference_serialIP == NULL)
 		"Failed to allocate memory",
 		" for reference residue serial numbers!\n",
 		"", "");
-	return -13;
+	return -22;
 	}
 
 /* Allocate memory for reference numeric residue codes: */
@@ -303,7 +416,7 @@ if (runtimeSP->reference_residue_codeIP == NULL)
 		"Failed to allocate memory",
 		" for reference numeric residue codes!\n",
 		"", "");
-        return -14;
+        return -23;
         }
 
 /* Allocate memory for reference hydrophobicity values: */
@@ -316,7 +429,7 @@ if (runtimeSP->reference_hydrophobicityP == NULL)
 		"Failed to allocate memory",
 		" for reference hydrophobicity values!\n",
 		"", "");
-	return -15;
+	return -24;
 	}
 
 /* Initialize the zoom factor: */
@@ -348,9 +461,15 @@ runtimeSP->sphere_radius = 8.0;
 /* Initialize the sliding window width: */
 runtimeSP->sliding_window_width = 11;
 
-/* Initialize flags related to the plotting of hydrophobicity functions: */
+/* Initialize flags related to hydrophobicity functions: */
 runtimeSP->average_hydrophobicityF = 0;
 runtimeSP->hydrophobic_momentF     = 0;
+runtimeSP->sided_hydrophobicityF   = 0;
+runtimeSP->function1F              = 0;
+runtimeSP->function2F              = 0;
+runtimeSP->function3F              = 0;
+runtimeSP->function4F              = 0;
+runtimeSP->function5F              = 0;
 
 /* Initialize range indices: */
 runtimeSP->range_startI = 0;
@@ -377,7 +496,7 @@ if (runtimeSP->template_atomSP == NULL)
                 "Failed to allocate memory for template atoms!\n",
                 "", "", "");
 	runtimeSP->max_template_atomsN = 0;
-        return -16;
+        return -25;
         }
 else runtimeSP->max_template_atomsN = MAXTEMPLATEATOMS;
 
@@ -418,7 +537,7 @@ if (runtimeSP->beta_cellSP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		       "Failed to allocate memory for beta cells!\n",
 		       "", "", "");
-	return -17;
+	return -26;
 	}
 
 /* Return positive value on success: */
