@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -118,7 +118,7 @@ winSP->pixmapF = 1;
 
 /* Parse colors: */
 /* (Note: be sure that pixmap is good, no check is done here!) */
-for (i = 1; i < colorsN + 1; i++)
+for (i = 1; i < (int) colorsN + 1; i++)
 	{
 	/** Copy the i-th line: **/
 	strncpy (line_copyA, *(dataPP + i), STRINGSIZE - 1);
@@ -148,10 +148,10 @@ for (i = 1; i < colorsN + 1; i++)
 
 /* Parse pixels and draw pixmap using default graphics context: */
 offset = winSP->colorsN + 1;
-for (j = 0; j < height; j++)
+for (j = 0; j < (int) height; j++)
 	{
 	offset = j + colorsN + 1;
-	for (i = 0; i < width; i++)
+	for (i = 0; i < (int) width; i++)
 		{
 		P = *(dataPP + offset) + i;
 		n = *P;
