@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -30,6 +30,9 @@ Return value:
 	(2) Zero if event is ignored.
 	(3) Negative on failure.
 
+Notes:
+	(1) Indentation is exceptionally 4 spaces.
+
 ========includes:============================================================*/
 
 #include <stdio.h>
@@ -82,6 +85,7 @@ int			residueI;
 AtomS			*first_atomSP;
 char			*residue_nameP;
 char			residue_nameA[RESNAMESIZE];
+char			serial_and_chainA[SHORTSTRINGSIZE];
 int			residue_name_length, string_length;
 int			text_width;
 int			line_x0 = 0, line_x1 = 0;
@@ -89,29 +93,29 @@ int			width, height;
 
 /* If main window contains Ramachandran plot: */
 if (guiSP->main_window_modeI == 1)
-	{
-	return RamaMouse_ (mol_complexSP, mol_complexesN,
-			   configSP, guiSP,
-			   nearest_atomSP, pixelsN,
-			   refreshI,
-			   motion_eventSP);
-	}
+    {
+    return RamaMouse_ (mol_complexSP, mol_complexesN,
+		       configSP, guiSP,
+		       nearest_atomSP, pixelsN,
+		       refreshI,
+		       motion_eventSP);
+    }
 
 /* If main window contains hydrophobicity plots: */
 else if (guiSP->main_window_modeI == 4)
-	{
-	return PlotMouse_ (runtimeSP, guiSP,
-			   nearest_atomSP, pixelsN, refreshI,
-			   motion_eventSP);
-	}
+    {
+    return PlotMouse_ (runtimeSP, guiSP,
+		       nearest_atomSP, pixelsN, refreshI,
+		       motion_eventSP);
+    }
 
 /* If main window contains sequence comparison: */
 else if (guiSP->main_window_modeI == 5)
-	{
-	return ComparisonMouse_ (runtimeSP, guiSP,
-				 nearest_atomSP, pixelsN,
-				 motion_eventSP);
-	}
+    {
+    return ComparisonMouse_ (runtimeSP, guiSP,
+			     nearest_atomSP, pixelsN,
+			     motion_eventSP);
+    }
 
 /* If the event came from child window, return zero: */
 if (motion_eventSP->subwindow != None) return 0;
@@ -220,109 +224,109 @@ XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
 screen_y0 += text_line_height;
 phi = curr_residueSP->phi;
 if (phi == BADDIHEDANGLE)
-	{
-	strcpy (stringA, "phi: missing");
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    strcpy (stringA, "phi: missing");
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 else
-	{
-	phi *= RAD_TO_DEG;
-	sprintf (stringA, "phi: %7.2f", phi);
-	stringA[STRINGSIZE - 1] = '\0';
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    phi *= RAD_TO_DEG;
+    sprintf (stringA, "phi: %7.2f", phi);
+    stringA[STRINGSIZE - 1] = '\0';
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 
 /* The angle psi (see dihedral_angles.c for definition): */
 screen_y0 += text_line_height;
 psi = curr_residueSP->psi;
 if (psi == BADDIHEDANGLE)
-	{
-	strcpy (stringA, "psi: missing");
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    strcpy (stringA, "psi: missing");
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 else
-	{
-	psi *= RAD_TO_DEG;
-	sprintf (stringA, "psi: %7.2f", psi);
-	stringA[STRINGSIZE - 1] = '\0';
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    psi *= RAD_TO_DEG;
+    sprintf (stringA, "psi: %7.2f", psi);
+    stringA[STRINGSIZE - 1] = '\0';
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 
 /* The angle omega (see dihedral_angles.c for definition): */
 screen_y0 += text_line_height;
 omega = curr_residueSP->omega;
 if (omega == BADDIHEDANGLE)
-	{
-	strcpy (stringA, "ome: missing");
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    strcpy (stringA, "ome: missing");
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 else
-	{
-	omega *= RAD_TO_DEG;
-	sprintf (stringA, "ome: %7.2f", omega);
-	stringA[STRINGSIZE - 1] = '\0';
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    omega *= RAD_TO_DEG;
+    sprintf (stringA, "ome: %7.2f", omega);
+    stringA[STRINGSIZE - 1] = '\0';
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 
 /* The angle chi1 (see dihedral_angles.c for definition): */
 screen_y0 += text_line_height;
 chi1 = curr_residueSP->chi1;
 if (chi1 == BADDIHEDANGLE)
-	{
-	strcpy (stringA, "chi1:    -");
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    strcpy (stringA, "chi1:    -");
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 else
-	{
-	chi1 *= RAD_TO_DEG;
-	sprintf (stringA, "chi1:%7.2f", chi1);
-	stringA[STRINGSIZE - 1] = '\0';
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    chi1 *= RAD_TO_DEG;
+    sprintf (stringA, "chi1:%7.2f", chi1);
+    stringA[STRINGSIZE - 1] = '\0';
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+    screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 
 /* The angle chi2 (see dihedral_angles.c for definition): */
 screen_y0 += text_line_height;
 chi2 = curr_residueSP->chi2;
 if (chi2 == BADDIHEDANGLE)
-	{
-	strcpy (stringA, "chi2:    -");
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    strcpy (stringA, "chi2:    -");
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 else
-	{
-	chi2 *= RAD_TO_DEG;
-	sprintf (stringA, "chi2:%7.2f", chi2);
-	stringA[STRINGSIZE - 1] = '\0';
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    chi2 *= RAD_TO_DEG;
+    sprintf (stringA, "chi2:%7.2f", chi2);
+    stringA[STRINGSIZE - 1] = '\0';
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 
 /* The angle chi3 (see dihedral_angles.c for definition): */
 screen_y0 += text_line_height;
 chi3 = curr_residueSP->chi3;
 if (chi3 == BADDIHEDANGLE)
-	{
-	strcpy (stringA, "chi3:    -");
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    strcpy (stringA, "chi3:    -");
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 else
-	{
-	chi3 *= RAD_TO_DEG;
-	sprintf (stringA, "chi3:%7.2f", chi3);
-	stringA[STRINGSIZE - 1] = '\0';
-	XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, strlen (stringA));
-	}
+    {
+    chi3 *= RAD_TO_DEG;
+    sprintf (stringA, "chi3:%7.2f", chi3);
+    stringA[STRINGSIZE - 1] = '\0';
+    XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, strlen (stringA));
+    }
 
 /* x coordinate: */
 screen_y0 += text_line_height;
@@ -354,115 +358,135 @@ XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
 /* Write  the sequence neighborhood  of the */
 /* residue under the pointer, if requested: */
 if (configSP->show_sequence_neighborhoodF)
+    {
+    /* The central residue index: */
+    central_residueI = curr_atomSP->residue_arrayI;
+
+    /* Space half-width: */
+    space_width = XTextWidth (guiSP->main_winS.fontSP, " ", 1);
+    space_half_width = space_width / 2;
+
+    /* Indices of the first and the last residue in the neighbourhood: */
+    first_residueI = central_residueI - NEIGH_HALF_WIDTH;
+    if (first_residueI < 0) first_residueI = 0;
+    last_residueI = central_residueI + NEIGH_HALF_WIDTH;
+    if (last_residueI >= (int) curr_mol_complexSP->residuesN)
 	{
-	/* The central residue index: */
-	central_residueI = curr_atomSP->residue_arrayI;
-
-	/* Space half-width: */
-	space_width = XTextWidth (guiSP->main_winS.fontSP, " ", 1);
-	space_half_width = space_width / 2;
-
-	/* Indices of the first and the last residue in the neighbourhood: */
-	first_residueI = central_residueI - NEIGH_HALF_WIDTH;
-	if (first_residueI < 0) first_residueI = 0;
-	last_residueI = central_residueI + NEIGH_HALF_WIDTH;
-	if (last_residueI >= curr_mol_complexSP->residuesN)
-		{
-		last_residueI = (int) curr_mol_complexSP->residuesN - 1;
-		}
-
-	/* Prepare the string with the left part of the neighborhood: */
-	stringA[0] = '\0';
-	residue_name_length = RESNAMESIZE - 1;
-	strcat (stringA, " ");
-	for (residueI = first_residueI; residueI <= last_residueI; residueI++)
-		{
-		/* The string width, without the central residue: */
-		if (residueI == central_residueI)
-			{
-			string_length = strlen (stringA);
-			line_x0 = XTextWidth (guiSP->main_winS.fontSP,
-					      stringA, string_length) -
-					      space_half_width;
-			}
-
-		/* Pointer to current residue: */
-		curr_residueSP = curr_mol_complexSP->residueSP + residueI;
-
-		/* Pointer to the first atom of the current residue: */
-		first_atomSP = curr_mol_complexSP->atomSP +
-			       curr_residueSP->residue_startI;
-
-		/* Pointer to residue name: */
-		residue_nameP = first_atomSP->raw_atomS.pure_residue_nameA;
-
-		/* Add the residue name to the output string: */
-		strncpy (residue_nameA, residue_nameP, residue_name_length);
-		residue_nameA[residue_name_length] = '\0';
-		strcat (stringA, residue_nameA);
-		strcat (stringA, " ");
-
-		/* The string width, including the central residue: */
-		if (residueI == central_residueI)
-			{
-			string_length = strlen (stringA);
-			line_x1 = XTextWidth (guiSP->main_winS.fontSP,
-					      stringA, string_length) -
-					      space_half_width;
-			}
-		}
-
-	/* String length: */
-	string_length = strlen (stringA);
-
-	/* Text width: */
-	text_width = XTextWidth (guiSP->main_winS.fontSP,
-				 stringA, string_length);
-
-	/* Prepare text background color: */
-	XSetForeground (guiSP->displaySP, guiSP->theGCA[0],
-			guiSP->main_winS.bg_colorID);
-
-	/* Refresh the string background: */
-	screen_x0 = 1;
-	screen_y0 = 1;
-	width = guiSP->control_winS.x0 - guiSP->main_winS.border_width - 2;
-	if (width < 0) width = 0;
-	height = guiSP->main_winS.font_height + 4;
-	XFillRectangle (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
-			screen_x0, screen_y0,
-			(unsigned int) width, (unsigned int) height);
-
-        /* Prepare text color: */
-	XSetForeground (guiSP->displaySP, guiSP->theGCA[0],
-			guiSP->main_winS.fg_colorID);
-
-	/* Draw the bounding rectangle: */
-	XDrawRectangle (guiSP->displaySP, guiSP->main_winS.ID,
-			guiSP->theGCA[0],
-			screen_x0, screen_y0,
-			(unsigned int) width, (unsigned int) height);
-
-	/* Draw the string which contains sequence neighborhood: */
-	screen_x0 = guiSP->control_winS.x0 / 2 - text_width / 2;
-	screen_y0 = guiSP->main_winS.font_height + 1;
-	XDrawString (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
-		     screen_x0, screen_y0, stringA, string_length);
-
-	/* Draw rectangle bounding the central residue: */
-	line_x0 += guiSP->control_winS.x0 / 2 - text_width / 2;
-	line_x1 += guiSP->control_winS.x0 / 2 - text_width / 2;
-	width = line_x1 - line_x0 + 1;
-	if (width < 0) width = 0;
-	height = guiSP->main_winS.font_height - 1;
-	if (height < 0) height = 0;
-	screen_y0 = height;
-	XDrawRectangle (guiSP->displaySP, guiSP->main_winS.ID,
-			guiSP->theGCA[0],
-			line_x0, 4,
-			(unsigned int) width, (unsigned int) height);
+	last_residueI = (int) curr_mol_complexSP->residuesN - 1;
 	}
 
+    /* Prepare the string: */
+    stringA[0] = '\0';
+    residue_name_length = RESNAMESIZE - 1;
+    strcat (stringA, " ");
+    for (residueI = first_residueI; residueI <= last_residueI; residueI++)
+	{
+	/* The string width, without the central residue: */
+	if (residueI == central_residueI)
+	    {
+	    string_length = strlen (stringA);
+	    line_x0 = XTextWidth (guiSP->main_winS.fontSP,
+				  stringA, string_length) - space_half_width;
+	    }
+
+	/* Pointer to current residue: */
+	curr_residueSP = curr_mol_complexSP->residueSP + residueI;
+
+	/* Pointer to the first atom of the current residue: */
+	first_atomSP = curr_mol_complexSP->atomSP +
+		       curr_residueSP->residue_startI;
+
+	/* Pointer to residue name: */
+	residue_nameP = first_atomSP->raw_atomS.pure_residue_nameA;
+
+	/* Add the residue name to the output string: */
+	strncpy (residue_nameA, residue_nameP, residue_name_length);
+	residue_nameA[residue_name_length] = '\0';
+	strcat (stringA, residue_nameA);
+
+	/* If the output should be  verbose,  i.e.  should contain */
+	/* residue serial numbers and chain identifiers, add them: */
+	if (configSP->show_sequence_neighborhoodF == 2)
+	    {
+	    /* If chain identifier is trivial (space character), ignore it: */
+	    if (first_atomSP->raw_atomS.chainID == ' ')
+		{
+		sprintf (serial_and_chainA, "%d",
+			 first_atomSP->raw_atomS.residue_sequenceI);
+		serial_and_chainA[SHORTSTRINGSIZE - 1] = '\0';
+		}
+	    /* If chain identifier is not trivial, add it: */
+	    else
+		{
+		sprintf (serial_and_chainA, "%d%c",
+			 first_atomSP->raw_atomS.residue_sequenceI,
+			 first_atomSP->raw_atomS.chainID);
+		serial_and_chainA[SHORTSTRINGSIZE - 1] = '\0';
+		}
+
+	    /* Append the serial number and chain ID to residue name: */
+	    strcat (stringA, serial_and_chainA);
+	    }
+
+	/* Add a single space: */
+	strcat (stringA, " ");
+
+	/* The string width, including the central residue: */
+	if (residueI == central_residueI)
+	    {
+	    string_length = strlen (stringA);
+	    line_x1 = XTextWidth (guiSP->main_winS.fontSP,
+				  stringA, string_length) - space_half_width;
+	    }
+	}
+
+    /* String length: */
+    string_length = strlen (stringA);
+
+    /* Text width: */
+    text_width = XTextWidth (guiSP->main_winS.fontSP, stringA, string_length);
+
+    /* Prepare text background color: */
+    XSetForeground (guiSP->displaySP, guiSP->theGCA[0],
+		    guiSP->main_winS.bg_colorID);
+
+    /* Refresh the string background: */
+    screen_x0 = 1;
+    screen_y0 = 1;
+    width = guiSP->control_winS.x0 - guiSP->main_winS.border_width - 2;
+    if (width < 0) width = 0;
+    height = guiSP->main_winS.font_height + 4;
+    XFillRectangle (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
+		    screen_x0, screen_y0,
+		    (unsigned int) width, (unsigned int) height);
+
+    /* Prepare text color: */
+    XSetForeground (guiSP->displaySP, guiSP->theGCA[0],
+    guiSP->main_winS.fg_colorID);
+
+    /* Draw the bounding rectangle: */
+    XDrawRectangle (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
+		    screen_x0, screen_y0,
+		    (unsigned int) width, (unsigned int) height);
+
+    /* Draw the string which contains sequence neighborhood: */
+    screen_x0 = guiSP->control_winS.x0 / 2 - text_width / 2;
+    screen_y0 = guiSP->main_winS.font_height + 1;
+    XDrawString (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
+		 screen_x0, screen_y0, stringA, string_length);
+
+    /* Draw rectangle bounding the central residue: */
+    line_x0 += guiSP->control_winS.x0 / 2 - text_width / 2;
+    line_x1 += guiSP->control_winS.x0 / 2 - text_width / 2;
+    width = line_x1 - line_x0 + 1;
+    if (width < 0) width = 0;
+    height = guiSP->main_winS.font_height - 1;
+    if (height < 0) height = 0;
+    XDrawRectangle (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
+		    line_x0, 4,
+		    (unsigned int) width, (unsigned int) height);
+    }
+
 /* Return positive value: */
 return 1;
 }
