@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2003 Damir Zucic */
+/* Copyright (C) 2000-2004 Damir Zucic */
 
 
 /* Structures used in garlic program. */
@@ -74,7 +74,8 @@ typedef struct		/* ConfigS */
 	/* Control window flag (0 = hidden, 1 = visible): */
 	int		show_control_windowF;
 
-	/* Sequence neighborhood flag: */
+	/* Sequence neighborhood flag  (0 = hide, 1 = show residue names, */
+	/* 2 = show residue names, serial numbers and chain identifiers): */
 	int		show_sequence_neighborhoodF;
 
 	/* Stereo flag (0 = draw mono image, 1 = draw stereo image): */
@@ -1175,6 +1176,20 @@ typedef struct		/* RuntimeS */
 	size_t		atom1_arrayI;               /* Array indices of      */
 	size_t		atom2_arrayI;               /* these two atoms       */
 
+	int		hydrophobicity_scaleI;
+	double		helix_step_angle;         /* degrees   */
+	double		arc_angle;                /* degrees   */
+	double		sphere_radius;            /* angstroms */
+	int		sliding_window_width;     /* residues  */
+	int		average_hydrophobicityF;  /* Average hydrophobicity  */
+	int		hydrophobic_momentF;      /* Hydrophobic moment      */
+	int		sided_hydrophobicityF;    /* Two sided-h. functions  */
+	int		function1F;               /* 1 = draw function F1    */
+	int		function2F;               /* 1 = draw function F2    */
+	int		function3F;               /* 1 = draw function F3    */
+	int		function4F;               /* 1 = draw function F4    */
+	int		function5F;               /* 1 = draw function F5    */
+
 	size_t		sequence_buffer_size;       /* Size of seq. buffer   */
 	size_t		residuesN;                  /* Sequence length       */
 	char		*sequenceP;                 /* Main sequence buffer  */
@@ -1186,6 +1201,15 @@ typedef struct		/* RuntimeS */
 	double		*hydrophobicityP;           /* Hydrophobicity values */
 	double		*average_hydrophobicityP;   /* For given  win. width */
 	double		*hydrophobic_momentP;       /* Absolute value        */
+	double		*larger_sided_hyphobP;      /* Sided h.,  upper line */
+	double		*smaller_sided_hyphobP;     /* Sided h., bottom line */
+	double		*function1P;		    /* Hydroph. function F1  */
+	double		*function2P;                /* Hydroph. function F2  */
+	double		*function3P;                /* Hydroph. function F3  */
+	double		*function4P;                /* Hydroph. function F4  */
+	double		*function5P;                /* Hydroph. function F5  */
+
+	int		*auxiliaryIP;               /* Aux. integer storage  */
 
 	size_t		reference_residuesN;        /* Reference seq. length */
 	char		*reference_sequenceP;       /* Reference seq. buffer */
@@ -1201,21 +1225,15 @@ typedef struct		/* RuntimeS */
 	int		segment_width;              /* Use to compare 2 seq. */
 	int		minimal_score;              /* Use to compare 2 seq. */
 
-	int		hydrophobicity_scaleI;
-	double		helix_step_angle;         /* degrees   */
-	double		arc_angle;                /* degrees   */
-	double		sphere_radius;            /* angstroms */
-	int		sliding_window_width;     /* residues  */
-	int		average_hydrophobicityF;
-	int		hydrophobic_momentF;
-
-	size_t		range_startI;             /* Residue range start     */
-	size_t		range_endI;               /* Residue range end       */
+	int		range_startI;             /* Residue range start     */
+	int		range_endI;               /* Residue range end       */
 
 	size_t		pattern_buffer_size;      /* Size of pattern buffer  */
 	size_t		pattern_length;           /* Number of positions     */
 	char		*patternP;                /* Pattern buffer          */
-	int		namesNA[MAXPATTLENGTH];   /* Residue names per pos.  */
+	int		namesNA[MAX_PATT_LENGTH]; /* Residue names per pos.  */
+	int		residues_in_patternN;	  /* Total number of resid.  */
+	int		pattern_tolerance;	  /* Numb. of allowed errors */
 
 	MolComplexS	*mol_complex1SP;          /* Involved in docking     */
 	MolComplexS	*mol_complex2SP;          /* Involved in docking     */
